==> Mapster-1.8.5.zip: Mapster/Locale/ruRU.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ruRU")
if not L then return end

L["Accuracy"] = "Точность"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Регулировка размера стрелки игрока на карте для улучшения её видимости."
L["Alpha"] = "Прозрачность"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Изменените масштаб карты, если не хотите видеть её развёрнутой на весь экран."
L["Coordinates"] = "Координаты"
L["Cursor"] = "Курсор"
L["Disable Mouse"] = "Отключить мышку"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой, например, измение зон."
L["EJ Icon Scale"] = "Масштаб иконки журнала встреч"
L["Enable Coordinates"] = "Включить координаты"
L["Enable FogClear"] = "Очищать туман"
L["Faded Alpha"] = "Faded Alpha"
L["FogClear"] = "Очистка тумана"
L["Font Size"] = "Размер шрифта"
L["Font Size on the normal map."] = "Размер шрифта на обычной карте."
L["Hide Map Button"] = "Скрыть иконку мини-карты"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "С помощью Mapster'а вы сможете управлять различными параметрами карты мира. Вы можете изменить стиль карты, добавить новую функциональность с помощью плагинов, а также сконфигурировать различные профили для каждого вашего персонажа."
L["Overlay Color"] = "Цвет подсветки"
L["Player"] = "Игрок"
L["PlayerArrow Scale"] = "Масштаб стрелки игрока"
L["POI Scale"] = "Масштаб POI"
L["Scale"] = "Масштаб"
L["Scale of the big map."] = "Масштаб большой карты."
L["Scale of the Encounter Journal Icons on the Map."] = "Масштабирование значков в журнале встреч на карте."
L["Scale of the POI Icons on the Map."] = "Масштаб иконок POI на карте."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Модуль координат добавляет строку с отображением вашего текущего местоположения, а также с положением курсора на карте."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Модуль очистки тумана войны делает скрытые (неисследованные) зоны видимыми, подсвечивая их особым цветом."
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "Когда вы начнете движение, карта будет исчезать до настроенного уровня Fade Alpha."
L["The transparency of the big map."] = "Прозрачность большой карты."
L["The transparency of the map while you are moving and the map is faded."] = "Прозрачность карты во время перемещения и карты исчезает."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Вы можете изменить прозрачность карты, что позволит вам видеть окружающую обстановку в то время, как карта будет открыта."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Вы можете управлять точностью координат, например, если вам нужные очень точные координаты - вы можете установить это значение как 2."

==> Mapster-1.11.0.zip: Mapster/Locale/ruRU.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ruRU")
if not L then return end

L["Accuracy"] = "Точность"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Регулировка размера стрелки игрока на карте для улучшения её видимости"
L["Alpha"] = "Прозрачность"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Изменените масштаб карты, если не хотите видеть её развёрнутой на весь экран."
L["Coordinates"] = "Координаты"
L["Cursor"] = "Курсор"
L["Disable Mouse"] = "Отключить мышку"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой, например, измение зон."
L["EJ Icon Scale"] = "Масштаб иконки журнала встреч"
L["Enable Coordinates"] = "Включить координаты"
L["Enable FogClear"] = "Очищать туман"
L["Faded Alpha"] = "Faded Alpha"
L["FogClear"] = "Очистка тумана"
L["Font Size"] = "Размер шрифта"
L["Font Size on the normal map."] = "Размер шрифта на обычной карте."
L["Hide Map Button"] = "Скрыть иконку мини-карты"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "С помощью Mapster'а вы сможете управлять различными параметрами карты мира. Вы можете изменить стиль карты, добавить новую функциональность с помощью плагинов, а также сконфигурировать различные профили для каждого вашего персонажа."
L["Overlay Color"] = "Цвет подсветки"
L["Player"] = "Игрок"
L["PlayerArrow Scale"] = "Масштаб стрелки игрока"
L["POI Scale"] = "Масштаб POI"
L["Scale"] = "Масштаб"
L["Scale of the big map."] = "Масштаб большой карты."
L["Scale of the Encounter Journal Icons on the Map."] = "Масштабирование значков в журнале встреч на карте."
L["Scale of the POI Icons on the Map."] = "Масштаб иконок POI на карте."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Модуль координат добавляет строку с отображением вашего текущего местоположения, а также с положением курсора на карте."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Модуль очистки тумана войны делает скрытые (неисследованные) зоны видимыми, подсвечивая их особым цветом."
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "Когда вы начнете движение, карта будет исчезать до настроенного уровня Fade Alpha."
L["The transparency of the big map."] = "Прозрачность большой карты."
L["The transparency of the map while you are moving and the map is faded."] = "Прозрачность карты во время перемещения и карты исчезает."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Вы можете изменить прозрачность карты, что позволит вам видеть окружающую обстановку в то время, как карта будет открыта."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Вы можете управлять точностью координат, например, если вам нужные очень точные координаты - вы можете установить это значение как 2."
